<?php

namespace Controllers;

use Services\AFProcessService as Service;

class AFProcessController
{
    const PRODUCT = "";

    public function __construct(Service $service)
    {
        $this->service = $service;
    }

    public function processesAF($order, $dataToSave, $cdSupplier)
    {
        self::saveDefaultMessage($order, $dataToSave, $cdSupplier);
        self::saveOrderMessage($order, $dataToSave);
        self::closeAF($dataToSave);
        self::updateAF($order, $dataToSave);
    }

    private function saveDefaultMessage($order, $dataToSave, $cdSupplier)
    {
        $nameSupplier = $this->service->getSupplierName($cdSupplier);
        $orderNumber = (string) $order->{'numero'};
        $messageCodeSupplier = '01';
        $message = "Pedido: $orderNumber Importação de AF Sapore/ $nameSupplier.";
        $this->service->setMessageAF($message, $dataToSave, $messageCodeSupplier);
    }

    private function saveOrderMessage($order, $dataToSave)
    {
        if (isset($order['STMENSAUTF'])) {
            $messageCodeSupplier = '02';
            $this->service->setMessageAF($order['STMENSAUTF'], $dataToSave['nrAutoForn'], $dataToSave['cdFilDest'], $messageCodeSupplier);
        }
    }

    private function closeAF($dataToSave)
    {
        $this->service->executeProcedureFechamentoAF($dataToSave);
    }

    private function updateAF($order, $dataToSave)
    {
        $nrOrder = (string) $order->numero;
        $this->service->updateAF($nrOrder, $dataToSave);
    }

    public function saveImportErrors($order, $dataSetErrors)
    {
        $importAFCode = (string) $order->numero;
        $cdFildest = (string) $order->{'cod-local'};
        $orderDate = (string) $order->{'data-pedido'};
        $orderErrors = $dataSetErrors['order'];
        $productErrors = $dataSetErrors['products'];

        $this->service->deleteLogImport($importAFCode, $cdFildest, $orderDate);
        self::importOrderError($importAFCode, $cdFildest, $orderDate, $orderErrors);
        self::importProductError($productErrors, $importAFCode, $cdFildest, $orderDate);
    }

    public function importOrderError($importAFCode, $cdFildest, $orderDate, $orderErrors)
    {
        if (is_array($orderErrors)) {
            foreach ($orderErrors as $error) {
                $this->service->setLogImport($importAFCode, $cdFildest, $orderDate, self::PRODUCT, $error);
            }
        }
    }

    public function importProductError($productErrors, $importAFCode, $cdFildest, $orderDate)
    {
        if (is_array($productErrors)) {
            foreach ($productErrors as $cdProduct => $error) {
                foreach ($error as $key => $strError) {
                    $cdProduct = $key === 'invalidCode' ? self::PRODUCT : $cdProduct;
                    $this->service->setLogImport($importAFCode, $cdFildest, $orderDate, $cdProduct, $strError);
                }
            }
        }
    }
}
